# Generated by Django 5.0 on 2023-12-22 16:47

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("emodjis", "0002_emoji_nsfw_emoji_team"),
    ]

    operations = [
        migrations.AddField(
            model_name="emoji",
            name="private",
            field=models.BooleanField(default=False),
        ),
    ]
